Search Results for *

Search results

Documents 1 to 100 of 1000 | Next 100 documents |  | Back

Docket # | Caption | Date Posted | Type

10-3381-cr | United States v. Banki | 02-22-2012 | OPN

10-2740-cr | United States v. Moore | 02-22-2012 | OPN

10-3381-cr | United States v. Banki | 02-21-2012 | OPN

09-4302-cv (L) | In re: Parmalat Securities Litigation | 02-21-2012 | OPN

10-2540-pr | Vega v. Walsh | 02-17-2012 | OPN

09-4152-cr | United States v. Hsu | 02-17-2012 | OPN

11-1088-cr | United States v. Gilliard | 02-17-2012 | OPN

11-1126 | United States v. Aleynikov | 02-16-2012 | OPN

10-1766-cr | United States v. Culbertson | 02-16-2012 | OPN

11-1591-cv | Baker v. Goldman Sachs & Co., et al. | 02-15-2012 | OPN

10-0065-cr | United States v. Coppola | 02-14-2012 | OPN

10-429-ag | Mathis v. SEC | 02-14-2012 | OPN

11-1233-cv | RICHARD WARE LEVITT, ESQ. V. DAVID H. BROOKS | 02-14-2012 | OPN

10-1039-pr | Garbutt v. Conway | 02-09-2012 | OPN

11-423-cv | Arditi v. Lighthouse Int'l | 02-09-2012 | OPN

09-5195-cr (L) | United States v. Knight | 02-06-2012 | OPN

10-1241-cv | Gallop v. Cheney | 02-03-2012 | OPN

10-1766-cr | United States v. Culbertson | 02-03-2012 | OPN

10-0910-cv | Scandinavian Reins. Co. Ltd. v. St. Paul Fire & Marine Ins. Co. | 02-03-2012 | OPN

08-4917-cv | Alliance for Open Society Int’l v. U.S. Agency for Int’l Dev. | 02-02-2012 | OPN

07-4449-cv (L) | Southerland v. City of New York | 02-02-2012 | OPN

10-1241-cv | Gallop v. Cheney | 02-02-2012 | OPN

09-3772-cv(L) | Lore v. City of Syracuse | 02-02-2012 | OPN

06-1871-cv | In Re: American Express Merchants’ Litigation | 02-01-2012 | OPN

09-5195-cr (L) | United States v. Knight | 02-01-2012 | OPN

10-3038-cv | Muto v. CBS Corporation | 02-01-2012 | OPN

10-5192 | Fowlkes v. Thomas | 01-31-2012 | OPN

09-0707-cr(L) | United States v. Cain, Jr., et al | 01-31-2012 | OPN

11-1150-cv(L) | Chevron v. Naranjo | 01-26-2012 | OPN

10-2331-pr | Collins v. Ercole | 01-26-2012 | OPN

10-2971-cr | United States v. Watkins | 01-26-2012 | OPN

10-70-cv | TIFD III-E, Inc v. United States | 01-24-2012 | OPN

10-2510-cv | Parker v. Ercole | 01-23-2012 | OPN

08-4463-cv | Huppe v. WPCS Int’l, Inc. | 01-20-2012 | OPN

10-3700-cr | United States v. Barner | 01-13-2012 | OPN

09-0994-cv (L) | Ognibene, et al. v. Parkes, et al. | 01-12-2012 | OPN

10-1925-cr | United States v. Keith J. Baker | 01-12-2012 | OPN

08-6166-cv(L) | Capital Management Select Fund Ltd., et al. v. Bennett et al. | 01-10-2012 | OPN

10-1048-cr | United States v. Collins | 01-09-2012 | OPN

10-3359-ag (L) | NLRB v. County Waste of Ulster | 01-06-2012 | OPN

10-0372-cv | New York Civil Liberties Union v. New York City Transit Authority | 01-04-2012 | OPN

09-4211-pr | Garcia v. USICE (Dept. of Homeland Security) | 12-29-2011 | OPN

10-3722-cv | Macpherson v. JPMorgan Chase Bank, N.A. | 12-23-2011 | OPN

10-1862-cv | Milgram v. Orthopedic Associates et al. | 12-23-2011 | OPN

10-4527-cr | United States v. Steppello | 12-23-2011 | OPN

10-1781-cv | USA v. Twenty Miljam-350 IED Jammers | 12-22-2011 | OPN

09-0994-cv (Lead) | Ognibene, et al. v. Parkes, et al. | 12-22-2011 | OPN

11-0462-cv | Skaftouros v. United States | 12-20-2011 | OPN

10-4220-cr | United States v. Cadet | 12-20-2011 | OPN

11-2576-cv | Tiberio v. Allergy Asthma Immunology of Rochester | 12-20-2011 | OPN

10-2026-cv | State of New York v. Solvent Chemical Co. et al. | 12-19-2011 | OPN

09-3293-cv | Amidax Trading Group v. S.W.I.F.T. SCRL | 12-19-2011 | OPN

08-6211-cr(L) | United States v. Ferguson | 12-19-2011 | OPN

10-224-pr | Rivera v. Cuomo | 12-16-2011 | OPN

10-903-cv | MLC v. Velez | 12-15-2011 | OPN

09-3925-cv | Figueiredo Ferraz v. Republic of Peru | 12-14-2011 | OPN

09-4704-cr (L) | USA v. Bourke | 12-14-2011 | OPN

10-4066-cv | India Steamship v. Kobil | 12-13-2011 | OPN

10-1420-cv | Nagle v. Marron | 12-12-2011 | OPN

06-2443-pr | Bennett v. USA | 12-09-2011 | OPN

10-4305-cv | Metz v. United States Life Insurance Company | 12-08-2011 | OPN

11-1802-cv | Dexter 345 Inc. v. Cuomo | 12-05-2011 | OPN

10-4248-cr (L) | United States v. Dugan | 12-05-2011 | OPN

10-561-pr | Cornell v. Kirkpatrick | 12-01-2011 | OPN

10-3550-cv | Lopez v. Jet Blue Airways | 12-01-2011 | OPN

10-0826 | Schwartz v.Merrill Lynch & Co. | 11-30-2011 | OPN

08-4211-cr (L) | United States v. Spies | 11-29-2011 | OPN

10-1862-cv | Milgram v. Orthopedic Associates et al. | 11-29-2011 | OPN

10-4090 | United States v. Leon | 11-23-2011 | OPN

09-90006-am | In re Fengling Liu | 11-22-2011 | OPN

10-4081-cv | Flagler v. Trainor | 11-21-2011 | OPN

10-1885 | United States v. Joseph L. Bruno | 11-16-2011 | OPN

10-4821-pr | Shepherd v. Goord | 11-15-2011 | OPN

10-1528 | Wilson v. Merril Lynch & Co. | 11-14-2011 | OPN

11-314-cv | Nike, Inc. v. Already LLC d/b/a Yums | 11-10-2011 | OPN

09-4958-cv | Doe v. Bin Laden | 11-07-2011 | OPN

10-4270 | Katzman v. Essex Waterfront Owners LLC | 11-04-2011 | OPN

09-4061-cv(L) | Novella v. Westchester County | 11-03-2011 | OPN

10-3399 | Ameriprise Financial Services, Inc. v. Beland | 11-03-2011 | OPN

10-1425-cv | Tepperwien v. Entergy Nuclear Operations | 10-31-2011 | OPN

10-1648-cv | Wachovia Bank v. VCG Special Opportunities Master Fund, Ltd. | 10-28-2011 | OPN

10-205-pr | Blackman v. Ercole | 10-27-2011 | OPN

08-3327 | United States v. Bahel | 10-26-2011 | OPN

10-1526-cr | United States v. Simmons | 10-26-2011 | OPN

10-3381-cr | United States v. Banki | 10-24-2011 | OPN

10-1199 | United States v. Rivera | 10-21-2011 | OPN

05-6408-cv (L) | Oneida Indian Nation v. Madison County | 10-20-2011 | OPN

11-37-cr (L) | United States v. Thorn | 10-20-2011 | OPN

08-1358-cv | Global Seafood Inc. v. Bantry Bay Mussels Ltd. | 10-20-2011 | OPN

Nos. 10-4934-cv (L); 10-4965-cv (Con) | Chem One, Ltd. v. M/V Rickmers Genoa | 10-20-2011 | OPN

10-792-cv (L) | Gearren v. McGraw-Hill Cos., Inc. | 10-19-2011 | OPN

10-0485-cv | Cunney v. Bd. of Trs. of Vill. of Grand View | 10-19-2011 | OPN

09-3804-cv | Gray v. Citigroup, Inc. | 10-19-2011 | OPN

09-4650-pr | Collazo v. Pagano | 10-17-2011 | OPN

10-3854-cv | Giovanniello v. ALM Media, LLC | 10-17-2011 | OPN

10-1241-cv | Gallop v. Cheney | 10-14-2011 | OPN

10-3943-cv | Joseph, et. al v. Hyman, et. al | 10-12-2011 | OPN

09-1556-cv (L) | John J. Fiero and Fiero Brothers, Inc. v. FINRA | 10-05-2011 | OPN

10-4132-cv | Rojas v. The Roman Catholic Diocese of Rochester | 10-04-2011 | OPN

10-2994-cr | United States v. Leslie | 10-03-2011 | OPN

Documents 1 to 100 of 1000 | Next 100 documents |  | Back